import "core-js/modules/web.dom-collections.iterator.js";

/**
 * File: /src/util.ts
 * Project: @native-theme-ui/core
 * File Created: 28-02-2022 07:21:50
 * Author: Clay Risser
 * -----
 * Last Modified: 05-07-2022 07:23:36
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export function splitTouchableProps(props) {
  const clonedProps = { ...props
  };
  const touchableProps = {};
  Object.entries(clonedProps).forEach(_ref => {
    let [key, prop] = _ref;

    if (key.length >= 3 && key.substring(0, 2) === "on" && key[2] === key[2].toUpperCase()) {
      touchableProps[key] = prop;
      delete clonedProps[key];
    }
  });
  return [clonedProps, touchableProps];
}
export function createSplitProps(propsSetsMap, sxsSetsMap) {
  const lastPropsSetId = "baseProps";
  const lastSxsSetId = "baseSx";
  return function (props) {
    let sx = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    const propsMap = {};
    const sxsMap = {};
    if (lastPropsSetId) propsMap[lastPropsSetId] = {};
    if (lastSxsSetId) sxsMap[lastSxsSetId] = {};

    if (propsSetsMap) {
      Object.keys(propsSetsMap).forEach(propsSetId => propsMap[propsSetId] = {});
      const clonedProps = { ...props
      };
      const propsSetsIds = Object.keys(propsSetsMap);
      Object.entries(clonedProps).forEach(_ref2 => {
        let [key, prop] = _ref2;

        for (const propsSetId of propsSetsIds) {
          const propsSet = propsMap[propsSetId];
          const matcher = propsSetsMap[propsSetId];

          if (Array.isArray(matcher) ? new Set(matcher).has(key) : !!key.match(matcher)) {
            propsSet[key] = prop;
            return;
          }
        }

        if (lastPropsSetId && key !== "sx") propsMap[lastPropsSetId][key] = prop;
      });
    }

    if (sxsSetsMap) {
      Object.keys(sxsSetsMap).forEach(sxsSetId => sxsMap[sxsSetId] = {});
      const sxsSetsIds = Object.keys(sxsSetsMap);
      Object.entries(sx).forEach(_ref3 => {
        let [key, value] = _ref3;

        for (const sxsSetId of sxsSetsIds) {
          const sxsSet = sxsMap[sxsSetId];
          const matcher = sxsSetsMap[sxsSetId];

          if (Array.isArray(matcher) ? new Set(matcher).has(key) : !!key.match(matcher)) {
            sxsSet[key] = value;
            return;
          }
        }

        if (lastSxsSetId) sxsMap[lastSxsSetId][key] = value;
      });
    }

    return { ...propsMap,
      ...sxsMap
    };
  };
}
//# sourceMappingURL=util.js.map